==> json-schema-for-humans-0.34.1.tar.gz: json-schema-for-humans-0.34.1/docs/examples/examples_md_default/complex_const.md <==
# Schema Docs

- [1. Property `root > oneOf > 1st constant`](#oneOf_i0)
- [2. Property `root > oneOf > 2nd constant`](#oneOf_i1)

| Type                      | `combining`                                                               |
| ------------------------- | ------------------------------------------------------------------------- |
| **Additional properties** | [[Any type: allowed]](# "Additional Properties of any type are allowed.") |
|                           |                                                                           |

| One of(Option)            |
| ------------------------- |
| [1st constant](#oneOf_i0) |
| [2nd constant](#oneOf_i1) |
|                           |

## <a name="oneOf_i0"></a>1. Property `root > oneOf > 1st constant`

**Title:** 1st constant

| Type                      | `const`                                                                   |
| ------------------------- | ------------------------------------------------------------------------- |
| **Additional properties** | [[Any type: allowed]](# "Additional Properties of any type are allowed.") |
|                           |                                                                           |

Specific value: `[
    1,
    2
]`

## <a name="oneOf_i1"></a>2. Property `root > oneOf > 2nd constant`

**Title:** 2nd constant

| Type                      | `const`                                                                   |
| ------------------------- | ------------------------------------------------------------------------- |
| **Additional properties** | [[Any type: allowed]](# "Additional Properties of any type are allowed.") |
|                           |                                                                           |

Specific value: `{
    "a_key": "a_value",
    "another_key": "another_value"
}`

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | N/A                |
|                      |                    |

----------------------------------------------------------------------------------------------------------------------------
Generated using [json-schema-for-humans](https://github.com/coveooss/json-schema-for-humans) on date

==> json-schema-for-humans-0.34.3.tar.gz: json-schema-for-humans-0.34.3/docs/examples/examples_md_default/complex_const.md <==
# Schema Docs

- [1. Property `root > oneOf > 1st constant`](#oneOf_i0)
- [2. Property `root > oneOf > 2nd constant`](#oneOf_i1)
- [3. Property `root > oneOf > 0`](#oneOf_i2)

| Type                      | `combining`                                                               |
| ------------------------- | ------------------------------------------------------------------------- |
| **Additional properties** | [[Any type: allowed]](# "Additional Properties of any type are allowed.") |
|                           |                                                                           |

| One of(Option)            |
| ------------------------- |
| [1st constant](#oneOf_i0) |
| [2nd constant](#oneOf_i1) |
| [0](#oneOf_i2)            |
|                           |

## <a name="oneOf_i0"></a>1. Property `root > oneOf > 1st constant`

**Title:** 1st constant

| Type                      | `const`                                                                   |
| ------------------------- | ------------------------------------------------------------------------- |
| **Additional properties** | [[Any type: allowed]](# "Additional Properties of any type are allowed.") |
|                           |                                                                           |

Specific value: `[
    1,
    2
]`

## <a name="oneOf_i1"></a>2. Property `root > oneOf > 2nd constant`

**Title:** 2nd constant

| Type                      | `const`                                                                   |
| ------------------------- | ------------------------------------------------------------------------- |
| **Additional properties** | [[Any type: allowed]](# "Additional Properties of any type are allowed.") |
|                           |                                                                           |

Specific value: `{
    "a_key": "a_value",
    "another_key": "another_value"
}`

## <a name="oneOf_i2"></a>3. Property `root > oneOf > 0`

**Title:** 0

| Type                      | `const`                                                                   |
| ------------------------- | ------------------------------------------------------------------------- |
| **Additional properties** | [[Any type: allowed]](# "Additional Properties of any type are allowed.") |
|                           |                                                                           |

Specific value: `0`

|                      | Array restrictions |
| -------------------- | ------------------ |
| **Min items**        | N/A                |
| **Max items**        | N/A                |
| **Items unicity**    | False              |
| **Additional items** | False              |
| **Tuple validation** | N/A                |
|                      |                    |

----------------------------------------------------------------------------------------------------------------------------
Generated using [json-schema-for-humans](https://github.com/coveooss/json-schema-for-humans) on date
